==> AQL-System-1.2.0-sources.jar: de/foellix/aql/converter/horndroid/ReportEntry.java <==
package de.foellix.aql.converter.horndroid;

import java.util.HashMap;
import java.util.Map;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({ "description", "result", "verbose" })
public class ReportEntry {

	@JsonProperty("description")
	private String description;
	@JsonProperty("result")
	private String result;
	@JsonProperty("verbose")
	private Boolean verbose;
	@JsonIgnore
	private Map<String, Object> additionalProperties = new HashMap<String, Object>();

	@JsonProperty("description")
	public String getDescription() {
		return this.description;
	}

	@JsonProperty("description")
	public void setDescription(String description) {
		this.description = description;
	}

	@JsonProperty("result")
	public String getResult() {
		return this.result;
	}

	@JsonProperty("result")
	public void setResult(String result) {
		this.result = result;
	}

	@JsonProperty("verbose")
	public Boolean getVerbose() {
		return this.verbose;
	}

	@JsonProperty("verbose")
	public void setVerbose(Boolean verbose) {
		this.verbose = verbose;
	}

	@JsonAnyGetter
	public Map<String, Object> getAdditionalProperties() {
		return this.additionalProperties;
	}

	@JsonAnySetter
	public void setAdditionalProperty(String name, Object value) {
		this.additionalProperties.put(name, value);
	}

}

==> AQL-System-2.0.0-sources.jar: de/foellix/aql/converter/horndroid/ReportEntry.java <==
package de.foellix.aql.converter.horndroid;

import java.util.HashMap;
import java.util.Map;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({ "description", "result", "verbose" })
public class ReportEntry {
	@JsonProperty("description")
	private String description;
	@JsonProperty("result")
	private String result;
	@JsonProperty("verbose")
	private Boolean verbose;
	@JsonIgnore
	private Map<String, Object> additionalProperties = new HashMap<>();

	@JsonProperty("description")
	public String getDescription() {
		return this.description;
	}

	@JsonProperty("description")
	public void setDescription(String description) {
		this.description = description;
	}

	@JsonProperty("result")
	public String getResult() {
		return this.result;
	}

	@JsonProperty("result")
	public void setResult(String result) {
		this.result = result;
	}

	@JsonProperty("verbose")
	public Boolean getVerbose() {
		return this.verbose;
	}

	@JsonProperty("verbose")
	public void setVerbose(Boolean verbose) {
		this.verbose = verbose;
	}

	@JsonAnyGetter
	public Map<String, Object> getAdditionalProperties() {
		return this.additionalProperties;
	}

	@JsonAnySetter
	public void setAdditionalProperty(String name, Object value) {
		this.additionalProperties.put(name, value);
	}
}
